@@ -93,7 +93,7 @@ def _node_as_tensor(node: Dict[str, np.ndarray]) -> Dict[str, np.ndarray]:
 class TpuRunner:
     """Runner for IVA TPU."""
 
-    def __init__(self, program_path: str, loop: Any = None, sync: bool = False, pyprocessing: bool = False) -> None:
+    def __init__(self, program_path: str, device_name: str = None, loop: Any = None, sync: bool = False, pyprocessing: bool = False) -> None:
 
         LOGGER.debug(f'Init TpuRunner with program: {program_path}')
 
@@ -105,8 +105,15 @@ class TpuRunner:
         if len(tpu_devices) < 1:
             raise EnvironmentError('No TPU devices found')
         
+        # import ipdb; ipdb.set_trace()
+        if device_name is None:
         # device_num = int(list(filter(str.isdigit, tpu_devices[0]))[0])
-        self._device = TPUDevice(tpu_devices[0].encode('utf-8'))
+            self._device = TPUDevice(tpu_devices[0].encode('utf-8'))
+        else:
+            full_name = [name for name in tpu_devices if device_name in name]
+            assert len(full_name) == 1, f'More than one device selected: {full_name}'
+            assert full_name[0] in tpu_devices, f'No such device: {device_name}'
+            self._device = TPUDevice(full_name[0].encode('utf-8'))
         
         if self._device.init() != 0:
             print('\n\nDevice error: {}\n'.format(self._device.get_error().decode('utf-8')))
